import matplotlib.pyplot as plt
from matplotlib import cm
import numpy as np
import scipy.stats as ss
X = np.linspace(0.1, 2.0, 1000)    #   mu_s
Y = np.linspace(0.4, 2.0, 100)     #   sigma_s
Xg, Yg = np.meshgrid(X, Y)

def Pc(mu, sgm):
    return  ss.norm.cdf(mu / ((1 + sgm**2)**0.5))

Z = np.empty((len(Y), len(X)))
for i in range(len(X)):
    for j in range(len(Y)):
        Z[j][i] = Pc(X[i], Y[j])

fig = plt.figure(figsize = (7,6))
ax = fig.add_subplot(111)
C = ax.contourf(Xg, Yg, Z, levels = 20)
ax.set_xlabel('$\mu_s$', fontsize = 16);
ax.set_ylabel('$\sigma_s$', fontsize = 16)
ax.set_title('Pc')
fig.colorbar(C, ax=ax, fraction=0.02, pad=0.1)
plt.tight_layout()
plt.savefig('FigPcCont.png')
plt.show()
